==> hpx-1.7.0.tar.gz: hpx-1.7.0/components/containers/partitioned_vector/include/hpx/components/containers/partitioned_vector/partitioned_vector_fwd.hpp <==
//  Copyright (c) 2014 Anuj R. Sharma
//  Copyright (c) 2014-2016 Hartmut Kaiser
//
//  SPDX-License-Identifier: BSL-1.0
//  Distributed under the Boost Software License, Version 1.0. (See accompanying
//  file LICENSE_1_0.txt or copy at http:// ww.boost.org/LICENSE_1_0.txt)

#pragma once

#include <hpx/config.hpp>
#include <hpx/components/containers/partitioned_vector/export_definitions.hpp>

#include <vector>

namespace hpx
{
    ///////////////////////////////////////////////////////////////////////////
    template <typename T, typename Data = std::vector<T>>
    class partitioned_vector;

    namespace segmented {

        template <typename T, typename Data> class local_vector_iterator;
        template <typename T, typename Data> class const_local_vector_iterator;

        template <typename T, typename Data, typename BaseIter>
        class local_raw_vector_iterator;
        template <typename T, typename Data, typename BaseIter>
        class const_local_raw_vector_iterator;

        template <typename T, typename Data> class vector_iterator;
        template <typename T, typename Data> class const_vector_iterator;

        template <typename T, typename Data, typename BaseIter>
        class segment_vector_iterator;
        template <typename T, typename Data, typename BaseIter>
        class const_segment_vector_iterator;

        template <typename T, typename Data, typename BaseIter>
        class local_segment_vector_iterator;
    }

    namespace server
    {
        template <typename T, typename Data = std::vector<T>>
        class partitioned_vector;

        template <typename T, typename Data = std::vector<T>>
        class partitioned_vector_partition;
    }
}

==> hpx-1.11.0.tar.gz: hpx-1.11.0/components/containers/partitioned_vector/include/hpx/components/containers/partitioned_vector/partitioned_vector_fwd.hpp <==
//  Copyright (c) 2014 Anuj R. Sharma
//  Copyright (c) 2014-2024 Hartmut Kaiser
//
//  SPDX-License-Identifier: BSL-1.0
//  Distributed under the Boost Software License, Version 1.0. (See accompanying
//  file LICENSE_1_0.txt or copy at http:// ww.boost.org/LICENSE_1_0.txt)

#pragma once

#include <hpx/config.hpp>
#include <hpx/components/containers/partitioned_vector/export_definitions.hpp>

#include <vector>

namespace hpx {

    ///////////////////////////////////////////////////////////////////////////
    template <typename T, typename Data = std::vector<T>>
    class partitioned_vector;

    namespace segmented {

        template <typename T, typename Data>
        class local_vector_iterator;
        template <typename T, typename Data>
        class const_local_vector_iterator;

        template <typename T, typename Data, typename BaseIter>
        class local_raw_vector_iterator;
        template <typename T, typename Data, typename BaseIter>
        class const_local_raw_vector_iterator;

        template <typename T, typename Data>
        class vector_iterator;
        template <typename T, typename Data>
        class const_vector_iterator;

        template <typename T, typename Data, typename BaseIter>
        class segment_vector_iterator;
        template <typename T, typename Data, typename BaseIter>
        class const_segment_vector_iterator;

        template <typename T, typename Data, typename BaseIter>
        class local_segment_vector_iterator;
    }    // namespace segmented

    namespace server {

        template <typename T, typename Data = std::vector<T>>
        class partitioned_vector;

        template <typename T, typename Data = std::vector<T>>
        class partitioned_vector_partition;
    }    // namespace server
}    // namespace hpx
